@@ -1,6 +1,22 @@
 #ifndef H_NEWT_PR
 #define H_NEWT_PR
 
+#define COLORSET_ROOT 		NEWT_COLORSET_ROOT 
+#define COLORSET_BORDER 	NEWT_COLORSET_BORDER 
+#define COLORSET_WINDOW		NEWT_COLORSET_WINDOW
+#define COLORSET_SHADOW		NEWT_COLORSET_SHADOW
+#define COLORSET_TITLE		NEWT_COLORSET_TITLE
+#define COLORSET_BUTTON		NEWT_COLORSET_BUTTON
+#define COLORSET_ACTBUTTON	NEWT_COLORSET_ACTBUTTON
+#define COLORSET_CHECKBOX	NEWT_COLORSET_CHECKBOX
+#define COLORSET_ACTCHECKBOX	NEWT_COLORSET_ACTCHECKBOX
+#define COLORSET_ENTRY		NEWT_COLORSET_ENTRY
+#define COLORSET_LABEL		NEWT_COLORSET_LABEL
+#define COLORSET_LISTBOX	NEWT_COLORSET_LISTBOX
+#define COLORSET_ACTLISTBOX	NEWT_COLORSET_ACTLISTBOX
+#define COLORSET_TEXTBOX	NEWT_COLORSET_TEXTBOX
+#define COLORSET_ACTTEXTBOX	NEWT_COLORSET_ACTTEXTBOX
+
 void newtGotorc(int row, int col);
 void newtDrawBox(int left, int top, int width, int height, int shadow);
 void newtClearBox(int left, int top, int width, int height);
